==> mastercard_spendcontrols-1.0.3-py2-none-any.whl: mastercardspendcontrols/budgetdeclinewithbudgetid.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from resourceconfig import ResourceConfig

class BudgetdeclinewithbudgetId(BaseObject):
	"""
	
	"""

	__config = {
		
		"9b732a34-ea0d-4e01-8faf-d46dfdd958b5" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/budgets/{budgetId}", "delete", [], []),
		
		"5c919a95-5c46-49fa-94db-60fbd9b2b02c" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/budgets/{budgetId}", "read", [], []),
		
		"21239127-6711-402f-b3fe-a482f629a453" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/budgets/{budgetId}", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type BudgetdeclinewithbudgetId by id

		@param str id
		@return BudgetdeclinewithbudgetId of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("9b732a34-ea0d-4e01-8faf-d46dfdd958b5", BudgetdeclinewithbudgetId(mapObj))

	def delete(self):
		"""
		Delete object of type BudgetdeclinewithbudgetId

		@return BudgetdeclinewithbudgetId of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("9b732a34-ea0d-4e01-8faf-d46dfdd958b5", self)







	@classmethod
	def read(cls,id,criteria=None):
		"""
		Returns objects of type BudgetdeclinewithbudgetId by id and optional criteria
		@param str id
		@param dict criteria
		@return instance of BudgetdeclinewithbudgetId
		@raise ApiException: raised an exception from the response status
		"""
		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if criteria:
			if (isinstance(criteria,RequestMap)):
				mapObj.setAll(criteria.getObject())
			else:
				mapObj.setAll(criteria)

		return BaseObject.execute("5c919a95-5c46-49fa-94db-60fbd9b2b02c", BudgetdeclinewithbudgetId(mapObj))


	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type BudgetdeclinewithbudgetId

		@param Dict mapObj, containing the required parameters to create a new object
		@return BudgetdeclinewithbudgetId of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("21239127-6711-402f-b3fe-a482f629a453", BudgetdeclinewithbudgetId(mapObj))

==> mastercard_spendcontrols-1.0.4-py2-none-any.whl: mastercardspendcontrols/budgetdeclinewithbudgetid.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


from __future__ import absolute_import
from mastercardapicore import BaseObject
from mastercardapicore import RequestMap
from mastercardapicore import OperationConfig
from mastercardapicore import OperationMetadata
from mastercardspendcontrols import ResourceConfig

class BudgetdeclinewithbudgetId(BaseObject):
	"""
	
	"""

	__config = {
		
		"846024b8-51c3-407f-b32c-98db7d2c0071" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/budgets/{budgetId}", "delete", [], []),
		
		"389fb1b3-064b-42cf-bd1f-343e233d564b" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/budgets/{budgetId}", "read", [], []),
		
		"f04883bc-1f7c-4b37-a8b9-1702d89ad79e" : OperationConfig("/issuer/spendcontrols/v1/card/{uuid}/controls/declines/budgets/{budgetId}", "create", [], []),
		
	}

	def getOperationConfig(self,operationUUID):
		if operationUUID not in self.__config:
			raise Exception("Invalid operationUUID: "+operationUUID)

		return self.__config[operationUUID]

	def getOperationMetadata(self):
		return OperationMetadata(ResourceConfig.getInstance().getVersion(), ResourceConfig.getInstance().getHost(), ResourceConfig.getInstance().getContext(), ResourceConfig.getInstance().getJsonNative(), ResourceConfig.getInstance().getContentTypeOverride())





	@classmethod
	def deleteById(cls,id,map=None):
		"""
		Delete object of type BudgetdeclinewithbudgetId by id

		@param str id
		@return BudgetdeclinewithbudgetId of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""

		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if map:
			if (isinstance(map,RequestMap)):
				mapObj.setAll(map.getObject())
			else:
				mapObj.setAll(map)

		return BaseObject.execute("846024b8-51c3-407f-b32c-98db7d2c0071", BudgetdeclinewithbudgetId(mapObj))

	def delete(self):
		"""
		Delete object of type BudgetdeclinewithbudgetId

		@return BudgetdeclinewithbudgetId of the response of the deleted instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("846024b8-51c3-407f-b32c-98db7d2c0071", self)







	@classmethod
	def read(cls,id,criteria=None):
		"""
		Returns objects of type BudgetdeclinewithbudgetId by id and optional criteria
		@param str id
		@param dict criteria
		@return instance of BudgetdeclinewithbudgetId
		@raise ApiException: raised an exception from the response status
		"""
		mapObj =  RequestMap()
		if id:
			mapObj.set("id", id)

		if criteria:
			if (isinstance(criteria,RequestMap)):
				mapObj.setAll(criteria.getObject())
			else:
				mapObj.setAll(criteria)

		return BaseObject.execute("389fb1b3-064b-42cf-bd1f-343e233d564b", BudgetdeclinewithbudgetId(mapObj))


	@classmethod
	def create(cls,mapObj):
		"""
		Creates object of type BudgetdeclinewithbudgetId

		@param Dict mapObj, containing the required parameters to create a new object
		@return BudgetdeclinewithbudgetId of the response of created instance.
		@raise ApiException: raised an exception from the response status
		"""
		return BaseObject.execute("f04883bc-1f7c-4b37-a8b9-1702d89ad79e", BudgetdeclinewithbudgetId(mapObj))
